| Title: | Create Random Passwords |
|---|---|
| Description: | Create random passwords of letters, numbers and punctuation. |
| Authors: | Enrico Schumann [aut, cre] (ORCID: <https://orcid.org/0000-0001-7601-6576>) |
| Maintainer: | Enrico Schumann <[email protected]> |
| License: | GPL-3 |
| Version: | 1.0-1 |
| Built: | 2026-05-26 06:10:03 UTC |
| Source: | https://github.com/enricoschumann/password |
Create random passwords consisting of letters, numbers and punctuation characters.
password(n = 8, numbers = TRUE, case = TRUE, special = c("?", "!", "&", "%", "$"))password(n = 8, numbers = TRUE, case = TRUE, special = c("?", "!", "&", "%", "$"))
n |
integer: length (in the sense of |
numbers |
logical: include numbers 0 to 9? |
case |
logical: use upper and lower case letters? |
special |
a character vector of punctuation characters, or |
Creates a random combination of characters, using the function
sample.
A character vector of length one.
Enrico Schumann
password(8) password(10, numbers = FALSE, special = "/")password(8) password(10, numbers = FALSE, special = "/")