Welcome to ClientVPS Mirrors

Help for package password
Type: Package
Title: Create Random Passwords
Version: 1.0-1
Date: 2025-05-01
Maintainer: Enrico Schumann <es@enricoschumann.net>
Description: Create random passwords of letters, numbers and punctuation.
License: GPL-3
URL: https://enricoschumann.net/R/packages/password/ , https://github.com/enricoschumann/password
NeedsCompilation: no
Packaged: 2025-05-01 06:34:02 UTC; es19
Author: Enrico Schumann ORCID iD [aut, cre]
Repository: CRAN
Date/Publication: 2025-05-01 07:10:02 UTC

Random Password Generation

Description

Create random passwords consisting of letters, numbers and punctuation characters.

Usage

password(n = 8, numbers = TRUE, case = TRUE,
         special = c("?", "!", "&", "%", "$"))

Arguments

n

integer: length (in the sense of nchar) of password

numbers

logical: include numbers 0 to 9?

case

logical: use upper and lower case letters?

special

a character vector of punctuation characters, or FALSE.

Details

Creates a random combination of characters, using the function sample.

Value

A character vector of length one.

Author(s)

Enrico Schumann

Examples

password(8)
password(10, numbers = FALSE,  special = "/")

Need a high-speed mirror for your open-source project?
Contact our mirror admin team at info@clientvps.com.

This archive is provided as a free public service to the community.
Proudly supported by infrastructure from VPSPulse , RxServers , BuyNumber , UnitVPS , OffshoreName and secure payment technology by ArionPay.